/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.tez.dag.app.launcher;

import com.google.common.collect.Sets;
import org.apache.tez.dag.app.PluginWrapperTestHelpers;
import org.apache.tez.serviceplugins.api.ContainerLauncher;
import org.junit.Test;

public class TestContainerLauncherWrapper {

  @Test(timeout = 5000)
  public void testDelegation() throws Exception {
    PluginWrapperTestHelpers.testDelegation(ContainerLauncherWrapper.class, ContainerLauncher.class,
        Sets.newHashSet("getContainerLauncher", "dagComplete"));
  }

}
